import { PropType } from 'vue';
declare const CTimePicker: import("vue").DefineComponent<import("vue").ExtractPropTypes<{
    /**
     * Set if the component should use the 12/24 hour format. If `true` forces the interface to a 12-hour format. If `false` forces the interface into a 24-hour format. If `auto` the current locale will determine the 12 or 24-hour interface by default locales.
     *
     * @since 4.7.0
     */
    ampm: {
        type: PropType<boolean | "auto">;
        default: string;
        validator: (value: boolean | "auto") => boolean;
    };
    /**
     * Toggle visibility or set the content of cancel button.
     */
    cancelButton: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    /**
     * Sets the color context of the cancel button to one of CoreUI’s themed colors.
     *
     * @values 'primary', 'secondary', 'success', 'danger', 'warning', 'info', 'dark', 'light'
     */
    cancelButtonColor: {
        default: string;
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Size the cancel button small or large.
     *
     * @values 'sm', 'lg'
     */
    cancelButtonSize: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Set the cancel button variant to an outlined button or a ghost button.
     *
     * @values 'ghost', 'outline'
     */
    cancelButtonVariant: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Toggle visibility of the cleaner button.
     */
    cleaner: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Toggle visibility or set the content of confirm button.
     */
    confirmButton: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    /**
     * Sets the color context of the confirm button to one of CoreUI’s themed colors.
     *
     * @values 'primary', 'secondary', 'success', 'danger', 'warning', 'info', 'dark', 'light'
     */
    confirmButtonColor: {
        default: string;
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Size the confirm button small or large.
     *
     * @values 'sm', 'lg'
     */
    confirmButtonSize: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Set the confirm button variant to an outlined button or a ghost button.
     *
     * @values 'ghost', 'outline'
     */
    confirmButtonVariant: {
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Set container type for the component.
     */
    container: {
        type: PropType<"dropdown" | "inline">;
        default: string;
    };
    /**
     * Toggle the disabled state for the component.
     */
    disabled: BooleanConstructor;
    /**
     * Provide valuable, actionable feedback.
     *
     * @since 4.6.0
     */
    feedback: StringConstructor;
    /**
     * Provide valuable, actionable feedback.
     *
     * @since 4.6.0
     */
    feedbackInvalid: StringConstructor;
    /**
     * Provide valuable, actionable invalid feedback when using standard HTML form validation which applied two CSS pseudo-classes, `:invalid` and `:valid`.
     *
     * @since 4.6.0
     */
    feedbackValid: StringConstructor;
    /**
     * Specify a list of available hours using an array, or customize the filtering of hours through a function.
     *
     * @since 5.0.0
     */
    hours: {
        type: PropType<number[] | ((hour: number) => number[])>;
    };
    /**
     * The id global attribute defines an identifier (ID) that must be unique in the whole document.
     */
    id: StringConstructor;
    /**
     * Toggle visibility or set the content of the input indicator.
     */
    indicator: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Defines the delay (in milliseconds) for the input field's onChange event.
     *
     * @since 5.0.0
     */
    inputOnChangeDelay: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * Toggle the readonly state for the component.
     */
    inputReadOnly: BooleanConstructor;
    /**
     * Set component validation state to invalid.
     *
     * @since 4.6.0
     */
    invalid: {
        type: BooleanConstructor;
        default: undefined;
    };
    /**
     * Add a caption for a component.
     *
     * @since 4.6.0
     */
    label: StringConstructor;
    /**
     * Sets the default locale for components. If not set, it is inherited from the navigator.language.
     */
    locale: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Toggle the display of minutes, specify a list of available minutes using an array, or customize the filtering of minutes through a function.
     *
     * @since 5.0.0
     */
    minutes: {
        type: PropType<number[] | ((hour: number) => number[]) | boolean>;
        default: boolean;
    };
    /**
     * Set the name attribute for the input element.
     *
     * @since 5.3.0
     */
    name: StringConstructor;
    /**
     * Specifies a short hint that is visible in the input.
     */
    placeholder: {
        type: StringConstructor;
        default: string;
    };
    /**
     * When present, it specifies that must be filled out before submitting the form.
     *
     * @since 4.9.0
     */
    required: BooleanConstructor;
    /**
     * Toggle the display of seconds, specify a list of available seconds using an array, or customize the filtering of seconds through a function.
     *
     * @since 4.7.0
     */
    seconds: {
        type: PropType<number[] | ((hour: number) => number[]) | boolean>;
        default: boolean;
    };
    /**
     * Size the component small or large.
     *
     * @values 'sm', 'lg'
     */
    size: {
        type: StringConstructor;
        default: undefined;
        validator: (value: string) => boolean;
    };
    /**
     * Add helper text to the component.
     *
     * @since 4.6.0
     */
    text: StringConstructor;
    /**
     * Initial selected time.
     */
    time: (StringConstructor | DateConstructor)[];
    /**
     * Display validation feedback in a styled tooltip.
     *
     * @since 4.6.0
     */
    tooltipFeedback: BooleanConstructor;
    /**
     * Set component validation state to valid.
     *
     * @since 4.6.0
     */
    valid: {
        type: BooleanConstructor;
        default: undefined;
    };
    /**
     * Set the time picker variant to a roll or select.
     *
     * @values 'roll', 'select'
     */
    variant: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Toggle the visibility of the component.
     */
    visible: BooleanConstructor;
}>, () => import("vue").VNode<import("vue").RendererNode, import("vue").RendererElement, {
    [key: string]: any;
}>, {}, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, ("change" | "hide" | "show" | "update:time")[], "change" | "hide" | "show" | "update:time", import("vue").PublicProps, Readonly<import("vue").ExtractPropTypes<{
    /**
     * Set if the component should use the 12/24 hour format. If `true` forces the interface to a 12-hour format. If `false` forces the interface into a 24-hour format. If `auto` the current locale will determine the 12 or 24-hour interface by default locales.
     *
     * @since 4.7.0
     */
    ampm: {
        type: PropType<boolean | "auto">;
        default: string;
        validator: (value: boolean | "auto") => boolean;
    };
    /**
     * Toggle visibility or set the content of cancel button.
     */
    cancelButton: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    /**
     * Sets the color context of the cancel button to one of CoreUI’s themed colors.
     *
     * @values 'primary', 'secondary', 'success', 'danger', 'warning', 'info', 'dark', 'light'
     */
    cancelButtonColor: {
        default: string;
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Size the cancel button small or large.
     *
     * @values 'sm', 'lg'
     */
    cancelButtonSize: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Set the cancel button variant to an outlined button or a ghost button.
     *
     * @values 'ghost', 'outline'
     */
    cancelButtonVariant: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Toggle visibility of the cleaner button.
     */
    cleaner: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Toggle visibility or set the content of confirm button.
     */
    confirmButton: {
        type: (StringConstructor | BooleanConstructor)[];
        default: string;
    };
    /**
     * Sets the color context of the confirm button to one of CoreUI’s themed colors.
     *
     * @values 'primary', 'secondary', 'success', 'danger', 'warning', 'info', 'dark', 'light'
     */
    confirmButtonColor: {
        default: string;
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Size the confirm button small or large.
     *
     * @values 'sm', 'lg'
     */
    confirmButtonSize: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Set the confirm button variant to an outlined button or a ghost button.
     *
     * @values 'ghost', 'outline'
     */
    confirmButtonVariant: {
        type: StringConstructor;
        validator: (value: string) => boolean;
    };
    /**
     * Set container type for the component.
     */
    container: {
        type: PropType<"dropdown" | "inline">;
        default: string;
    };
    /**
     * Toggle the disabled state for the component.
     */
    disabled: BooleanConstructor;
    /**
     * Provide valuable, actionable feedback.
     *
     * @since 4.6.0
     */
    feedback: StringConstructor;
    /**
     * Provide valuable, actionable feedback.
     *
     * @since 4.6.0
     */
    feedbackInvalid: StringConstructor;
    /**
     * Provide valuable, actionable invalid feedback when using standard HTML form validation which applied two CSS pseudo-classes, `:invalid` and `:valid`.
     *
     * @since 4.6.0
     */
    feedbackValid: StringConstructor;
    /**
     * Specify a list of available hours using an array, or customize the filtering of hours through a function.
     *
     * @since 5.0.0
     */
    hours: {
        type: PropType<number[] | ((hour: number) => number[])>;
    };
    /**
     * The id global attribute defines an identifier (ID) that must be unique in the whole document.
     */
    id: StringConstructor;
    /**
     * Toggle visibility or set the content of the input indicator.
     */
    indicator: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Defines the delay (in milliseconds) for the input field's onChange event.
     *
     * @since 5.0.0
     */
    inputOnChangeDelay: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * Toggle the readonly state for the component.
     */
    inputReadOnly: BooleanConstructor;
    /**
     * Set component validation state to invalid.
     *
     * @since 4.6.0
     */
    invalid: {
        type: BooleanConstructor;
        default: undefined;
    };
    /**
     * Add a caption for a component.
     *
     * @since 4.6.0
     */
    label: StringConstructor;
    /**
     * Sets the default locale for components. If not set, it is inherited from the navigator.language.
     */
    locale: {
        type: StringConstructor;
        default: string;
    };
    /**
     * Toggle the display of minutes, specify a list of available minutes using an array, or customize the filtering of minutes through a function.
     *
     * @since 5.0.0
     */
    minutes: {
        type: PropType<number[] | ((hour: number) => number[]) | boolean>;
        default: boolean;
    };
    /**
     * Set the name attribute for the input element.
     *
     * @since 5.3.0
     */
    name: StringConstructor;
    /**
     * Specifies a short hint that is visible in the input.
     */
    placeholder: {
        type: StringConstructor;
        default: string;
    };
    /**
     * When present, it specifies that must be filled out before submitting the form.
     *
     * @since 4.9.0
     */
    required: BooleanConstructor;
    /**
     * Toggle the display of seconds, specify a list of available seconds using an array, or customize the filtering of seconds through a function.
     *
     * @since 4.7.0
     */
    seconds: {
        type: PropType<number[] | ((hour: number) => number[]) | boolean>;
        default: boolean;
    };
    /**
     * Size the component small or large.
     *
     * @values 'sm', 'lg'
     */
    size: {
        type: StringConstructor;
        default: undefined;
        validator: (value: string) => boolean;
    };
    /**
     * Add helper text to the component.
     *
     * @since 4.6.0
     */
    text: StringConstructor;
    /**
     * Initial selected time.
     */
    time: (StringConstructor | DateConstructor)[];
    /**
     * Display validation feedback in a styled tooltip.
     *
     * @since 4.6.0
     */
    tooltipFeedback: BooleanConstructor;
    /**
     * Set component validation state to valid.
     *
     * @since 4.6.0
     */
    valid: {
        type: BooleanConstructor;
        default: undefined;
    };
    /**
     * Set the time picker variant to a roll or select.
     *
     * @values 'roll', 'select'
     */
    variant: {
        type: StringConstructor;
        default: string;
        validator: (value: string) => boolean;
    };
    /**
     * Toggle the visibility of the component.
     */
    visible: BooleanConstructor;
}>> & Readonly<{
    onChange?: ((...args: any[]) => any) | undefined;
    onHide?: ((...args: any[]) => any) | undefined;
    onShow?: ((...args: any[]) => any) | undefined;
    "onUpdate:time"?: ((...args: any[]) => any) | undefined;
}>, {
    invalid: boolean;
    visible: boolean;
    size: string;
    disabled: boolean;
    variant: string;
    required: boolean;
    locale: string;
    container: "dropdown" | "inline";
    valid: boolean;
    tooltipFeedback: boolean;
    inputReadOnly: boolean;
    ampm: boolean | "auto";
    cancelButton: string | boolean;
    cancelButtonColor: string;
    cancelButtonSize: string;
    cancelButtonVariant: string;
    cleaner: boolean;
    confirmButton: string | boolean;
    confirmButtonColor: string;
    confirmButtonSize: string;
    indicator: boolean;
    inputOnChangeDelay: number;
    minutes: boolean | number[] | ((hour: number) => number[]);
    placeholder: string;
    seconds: boolean | number[] | ((hour: number) => number[]);
}, {}, {}, {}, string, import("vue").ComponentProvideOptions, true, {}, any>;
export { CTimePicker };
